package de.espirit.firstspirit.opt.example.universal.dataaccess.aspects;

import de.espirit.firstspirit.agency.SpecialistsBroker;
import de.espirit.firstspirit.agency.TransferAgent;
import de.espirit.firstspirit.client.plugin.dataaccess.DataAccessSession;
import de.espirit.firstspirit.client.plugin.dataaccess.aspects.transfer.HandlerHost;
import de.espirit.firstspirit.client.plugin.dataaccess.aspects.transfer.TransferHandling;
import de.espirit.firstspirit.opt.example.universal.dataaccess.TextBlocksObject;
import de.espirit.firstspirit.ui.gadgets.aspects.transfer.TransferType;

import org.jetbrains.annotations.NotNull;

import java.util.ArrayList;
import java.util.List;


/**
 * {@link DataAccessSession DataAccessSession<D>} Aspect: {@link TransferHandling TransferHandling<D>}
 *
 * This class advertises that the data access plug-in can handle drag-and-drop data, e.g. in order to process objects dropped
 * onto an FS_INDEX input component configured for use with this plug-in as a data source. It also registers handlers which
 * can process drop data of different flavors.
 */
public class TextBlocksTransferHandlingDataAccessSessionAspect implements TransferHandling<TextBlocksObject> {

	private final SpecialistsBroker _broker;


	public TextBlocksTransferHandlingDataAccessSessionAspect(@NotNull final SpecialistsBroker broker) {
		_broker = broker;
	}


	/**
	 * Instantiates and registers handler objects which process drop data of various flavors.
	 *
	 * @param host The host to register at.
	 */
	@Override
	public void registerHandlers(@NotNull final HandlerHost<TextBlocksObject> host) {
		final TransferAgent transferAgent = _broker.requireSpecialist(TransferAgent.TYPE);

		// Create and register a handler object that processes drop data of type TextBlocksObject.
		// This enables FS_INDEX input components which use this data access plug-in to receive text block entries dragged
		// and dropped e.g. from the Text Blocks report.
		final TransferType<TextBlocksObject> textBlocksObjectTransferType = transferAgent.getRawValueType(TextBlocksObject.class);
		host.registerHandler(textBlocksObjectTransferType, new TextBlocksObjectHandler());
	}


	/**
	 * Handler class which processes objects of type {@link TextBlocksObject}.
	 */
	private static class TextBlocksObjectHandler implements HandlerHost.Handler<TextBlocksObject, TextBlocksObject> {

		@NotNull
		@Override
		public List<TextBlocksObject> handle(@NotNull final List<TextBlocksObject> commodities) {
			return new ArrayList<TextBlocksObject>(commodities);
		}
	}
}
