package de.espirit.firstspirit.opt.example.universal.dataaccess.aspects;

import de.espirit.firstspirit.client.plugin.dataaccess.aspects.Updating;
import de.espirit.firstspirit.client.plugin.report.Parameter;
import de.espirit.firstspirit.client.plugin.report.ParameterMap;
import de.espirit.firstspirit.client.plugin.report.ParameterSelect;
import de.espirit.firstspirit.client.plugin.report.ParameterSelect.SelectItem;
import de.espirit.firstspirit.opt.example.universal.dataaccess.provider.TextBlocksObjectProvider;


import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.ArrayList;
import java.util.List;
import java.util.Optional;


/* Advertises that the {@link TextBlocksDataStream} class supports updating capabilities and provides the updateParameters
 * method which triggers the updating of parameters.
 */
public class TextBlocksUpdatingDataStreamBuilderAspect implements Updating {

	@NotNull
	private List<SelectItem> createWorkSelectItems(final Optional<List<String>> items){
		final ArrayList<SelectItem> list = new ArrayList<>();
		list.add(Parameter.Factory.createSelectItem("[work]", ""));
		if (items.isPresent()) {
			for (final String item : items.get()) {
				list.add(Parameter.Factory.createSelectItem(item, item));
			}
		}
		return list;
	}

	@Override
	public List<Parameter<?>> updateParameters(@Nullable final ParameterMap filter, final List<Parameter<?>> parameterFields) {
		final ArrayList<Parameter<?>> parameterList = new ArrayList<>();
		if (filter != null){
			final TextBlocksObjectProvider textBlocksObjectProvider = new TextBlocksObjectProvider();
			final String selectedGenre = filter.get(TextBlocksFilterableDataStreamBuilderAspect.GENRE);
			final String genre = selectedGenre == null ? "" : selectedGenre;
			for (final Parameter<?> field : parameterFields ){
				if (TextBlocksFilterableDataStreamBuilderAspect.WORKS.getName().equals(field.getName())){
					final List<SelectItem> workSelectItems = createWorkSelectItems(textBlocksObjectProvider.getWorks(genre));
					final ParameterSelect works = Parameter.Factory.createSelect(field.getName(), workSelectItems, filter.get(TextBlocksFilterableDataStreamBuilderAspect.WORKS));
					if (!works.equals(field)) { // only update parameter if actually updated
						parameterList.add(works);
					}
				}
			}
		}
		return parameterList;
	}

}
