package de.espirit.firstspirit.opt.example.universal.dataaccess.aspects.reporting;

import de.espirit.firstspirit.agency.OperationAgent;
import de.espirit.firstspirit.client.plugin.report.JavaClientExecutableReportItem;
import de.espirit.firstspirit.client.plugin.report.ReportContext;
import de.espirit.firstspirit.opt.example.universal.dataaccess.TextBlocksObject;
import de.espirit.firstspirit.ui.operations.RequestOperation;
import de.espirit.firstspirit.webedit.plugin.report.WebeditExecutableReportItem;

import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import javax.swing.Icon;


/**
 * Executable report item used to display a message box with the full title and text of a {@link TextBlocksObject}.
 */
public class TextBlocksClickExecutableReportItem implements JavaClientExecutableReportItem<TextBlocksObject>, WebeditExecutableReportItem<TextBlocksObject> {

	/**
	 * Indicates if the report item should be visible. In this plug-in's case, it always is.
	 *
	 * @param context The context to be considered for deciding upon the item being visible.
	 * @return {@code true}
	 */
	@Override
	public boolean isVisible(@NotNull final ReportContext<TextBlocksObject> context) {
		return true;
	}


	/**
	 * Indicates if the report item should be enabled. In this plug-in's case, it always is.
	 *
	 * @param context The context to be considered for deciding upon the item being enabled.
	 * @return {@code true}
	 */
	@Override
	public boolean isEnabled(@NotNull final ReportContext<TextBlocksObject> context) {
		return true;
	}


	/**
	 * Returns the item's icon for use in SiteArchitect.
	 * Since this executable report item is used as a click action on a report entry's snippet, no icon is needed, so {@code null} is always returned.
	 *
	 * @param context The context to be considered for providing the icon.
	 * @return {@code null}.
	 */
	@Nullable
	@Override
	public Icon getIcon(@NotNull final ReportContext<TextBlocksObject> context) {
		return null;
	}


	/**
	 * Returns the item's icon path for use in ContentCreator.
	 * Since this executable report item is used as a click action on a report entry's snippet, no icon is needed, so {@code null} is always returned.
	 *
	 * @param context The context to be considered for providing the path.
	 * @return {@code null}.
	 */
	@Nullable
	@Override
	public String getIconPath(@NotNull final ReportContext<TextBlocksObject> context) {
		return null;
	}


	/**
	 * Returns the item's label. Since this executable report item is used as a click action on a report entry's snippet, this label isn't actually necessary.
	 *
	 * @param context The context to be considered for providing a label.
	 * @return The item's label.
	 */
	@NotNull
	@Override
	public String getLabel(@NotNull final ReportContext<TextBlocksObject> context) {
		return "Show report item";
	}


	/**
	 * Opens an info message box which displays the {@link TextBlocksObject}'s title in the title bar and
	 * the object's text in the message area.
	 *
	 * @param context The context operating in.
	 */
	@Override
	public void execute(@NotNull final ReportContext<TextBlocksObject> context) {
		final TextBlocksObject reportObject = context.getObject();
		final OperationAgent operationAgent = context.requestSpecialist(OperationAgent.TYPE);
		if (operationAgent != null) {
			final RequestOperation requestOperation = operationAgent.getOperation(RequestOperation.TYPE);
			if (requestOperation != null) {
				requestOperation.setKind(RequestOperation.Kind.INFO);
				requestOperation.setTitle(reportObject.getTitle());
				// The standard buttons "OK" and "Cancel" are too much; a simple "Close" button is enough.
				requestOperation.addAnswer("Close");
				requestOperation.perform(reportObject.getText());
			}
		}
	}
}
