package de.espirit.firstspirit.opt.example.universal.dataaccess.aspects.reporting;

import de.espirit.firstspirit.client.plugin.dataaccess.DataAccessPlugin;
import de.espirit.firstspirit.client.plugin.dataaccess.aspects.ReportItemsProviding;
import de.espirit.firstspirit.client.plugin.report.ReportItem;
import de.espirit.firstspirit.opt.example.universal.dataaccess.TextBlocksObject;

import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.Collection;
import java.util.Collections;


/**
 * {@link DataAccessPlugin DataAccessPlugin<D>} Aspect: {@link ReportItemsProviding ReportItemsProviding <D>}
 *
 * This aspect class provides {@link ReportItem}s which implement interactive report functionality, available by either clicking
 * on a text block snippet in a report or on a button shown associated with a text block snippet in a report.
 */
public class TextBlocksReportItemsProvidingDataAccessPluginAspect implements ReportItemsProviding<TextBlocksObject> {

	/**
	 * Provides a click item which will be executed as a user performs a mouse click on a text block snippet's rectangle.
	 *
	 * @return A {@link ReportItem ReportItem<T>}, or {@code null} if none should be used.
	 */
	@Nullable
	@Override
	public ReportItem<TextBlocksObject> getClickItem() {
		return new TextBlocksClickExecutableReportItem();
	}


	/**
	 * Provides report items which will be shown as buttons associated with individual text block snippets.
	 *
	 * @return A {@link Collection} of {@link ReportItem ReportItem<T>}.
	 */
	@NotNull
	@Override
	public Collection<? extends ReportItem<TextBlocksObject>> getItems() {
		return Collections.emptyList();
	}
}
