package de.espirit.firstspirit.opt.example.universal.dataaccess.aspects.reporting;

import de.espirit.firstspirit.access.BaseContext;
import de.espirit.firstspirit.agency.Image;
import de.espirit.firstspirit.agency.ImageAgent;
import de.espirit.firstspirit.client.plugin.dataaccess.DataAccessPlugin;
import de.espirit.firstspirit.client.plugin.dataaccess.aspects.Reporting;
import de.espirit.firstspirit.opt.example.universal.dataaccess.TextBlocksDataAccessPlugin;

import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import javax.swing.ImageIcon;


/**
 * {@link DataAccessPlugin DataAccessPlugin<D>} Aspect: {@link Reporting}
 *
 * Marks the plug-in for use as a report in the SiteArchitect and ContentCreator report UIs and provides a report icon for that purpose.
 */
public class TextBlocksReportingDataAccessPluginAspect implements Reporting {

	private final BaseContext _context;


	public TextBlocksReportingDataAccessPluginAspect(@NotNull final BaseContext context) {
		_context = context;
	}


	/**
	 * Provides an icon for use with the Text Blocks report UI representations.
	 *
	 * @param active The requested state of the icon.
	 * @return A client-specific {@link Image} that contains data about the icon image.
	 */
	@Nullable
	@Override
	public Image<?> getReportIcon(final boolean active) {
		final ImageAgent imageAgent = _context.requireSpecialist(ImageAgent.TYPE);

		// Create an Image object based on the FirstSpirit client's requirements, always considering if an "active" state (report is opened)
		// or an "inactive" state is requested for the icon.
		if (_context.is(BaseContext.Env.WEBEDIT)) {
			// For use in ContentCreator, image files need to be rolled out to the project-specific ContentCreator web application's
			// directory. URLs are relative to that directory.
			if (active) {
				return imageAgent.getImageFromUrl("webclient_examples/media/dataaccess/textblocks/reportbutton_berry.png");
			} else {
				return imageAgent.getImageFromUrl("webclient_examples/media/dataaccess/textblocks/reportbutton_grey_light.png");
			}
		} else {
			// For SiteArchitect, the image file is loaded as a resource with a path relative to the class TextBlocksDataAccessPlugin.
			if (active) {
				return imageAgent.getImageFromIcon(new ImageIcon(TextBlocksDataAccessPlugin.class.getResource("resource/icon/reportbutton_grey_light.png")));
			} else {
				return imageAgent.getImageFromIcon(new ImageIcon(TextBlocksDataAccessPlugin.class.getResource("resource/icon/reportbutton_grey_dark.png")));
			}
		}
	}


}
