package de.espirit.firstspirit.opt.example.universal.gadget;

import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.Collection;


/**
 * Interface specifying the data value type used by the GOM and gadget interface implementations.
 */
public interface PhoneNumber extends Collection<Character> {

	/**
	 * Data markers used by {@link PhoneNumberValueEngineer} and the ContentCreator gadget's JavaScript controller.
	 */
	public enum Data {
		INTERNATIONAL,
		CITY,
		LOCAL
	}

	/**
	 * Return the international code or, if not defined, an empty {@link String}.
	 *
	 * @return The international code or "" if no code is defined.
	 */
	@NotNull
	public Integer getInternationalCode();

	/**
	 * Set the international code. If no international code should be defined, provide an empty {@link String}.
	 *
	 * @param internationalCode The international code (numeric characters only) or "".
	 */
	public void setInternationalCode(@Nullable final Integer internationalCode);

	/**
	 * Return the city code or, if not defined, an empty {@link String}.
	 *
	 * @return The city code or "" if no code is defined.
	 */
	@NotNull
	public String getCityCode();

	/**
	 * Set the city code. If no city code should be defined, provide an empty {@link String}.
	 *
	 * @param cityCode The city code (numeric characters only) or "".
	 */
	public void setCityCode(@Nullable final String cityCode);

	/**
	 * Return the local numer or, if not defined, an empty {@link String}.
	 *
	 * @return The local number or "" if no local number is defined.
	 */
	@NotNull
	public String getLocalNumber();

	/**
	 * Set the local number. If no local number should be defined, provide an empty {@link String}.
	 *
	 * @param localNumber The local number or "".
	 */
	public void setLocalNumber(@Nullable final String localNumber);

	/**
	 * Indicate if the object is to be considered empty. Depending on implementation, this may indicate one or more fields
	 * required to form the simplest phone number contain no value.
	 *
	 * @return {@code true} if the object is considered empty, {@link false} otherwise.
	 */
	public boolean isEmpty();
}
