package de.espirit.firstspirit.opt.example.universal.gadget;

import de.espirit.firstspirit.module.GadgetContext;
import de.espirit.firstspirit.webedit.server.gadgets.WebPluginGadget;
import de.espirit.firstspirit.webedit.server.gadgets.WebPluginGadgetFactory;

import org.jetbrains.annotations.NotNull;

import java.io.Serializable;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;


/**
 * Factory class for the Phone Number input component's web gadget. Instantiates a {@link WebPluginGadget} implementation
 * and associates required CSS and JavaScript files for client-side use.
 */
public class PhoneNumberWebGadgetFactory implements WebPluginGadgetFactory<GomPhoneNumber, HashMap<String, Serializable>> {

	@NotNull
	@Override
	public WebPluginGadget<HashMap<String, Serializable>> create(@NotNull final GadgetContext<GomPhoneNumber> context) {
		return new PhoneNumberWebGadget(context);
	}


	/**
	 * Indicate the name of the JavaScript controller object used for client-side gadget functionality. This name MUST
	 * match the name of the controller object (e.g. if the controller object is "top.ExampleGadgetController", this method
	 * must return "ExampleGadgetController").
	 *
	 * @return The name of the JavaScript controller object.
	 */
	@NotNull
	@Override
	public String getControllerName() {
		return "PhoneNumberWebGadget";
	}


	/**
	 * Indicate a {@link List} of URLs which provide JavaScript used to implement client-side gadget functionality.
	 *
	 * @return A {@link List} of URLs in {@link String} form.
	 */
	@NotNull
	@Override
	public List<String> getScriptUrls() {
		return Collections.singletonList("webclient_examples/gadget/phonenumber/PhoneNumberWebGadget.js");
	}


	/**
	 * Indicate a {@link List} of URLs which provide CSS definitions which style the client-side gadget user interface.
	 *
	 * @return A {@link List} of URLs in {@link String} form.
	 */
	@NotNull
	@Override
	public List<String> getStylesheetUrls() {
		return Collections.singletonList("webclient_examples/gadget/phonenumber/PhoneNumberWebGadget.css");
	}
}
