package de.espirit.firstspirit.opt.example.universal.report;

import de.espirit.firstspirit.access.BaseContext;
import de.espirit.firstspirit.access.script.Executable;
import de.espirit.firstspirit.agency.OperationAgent;
import de.espirit.firstspirit.agency.TransferAgent;
import de.espirit.firstspirit.ui.gadgets.aspects.transfer.CommodityContainer;
import de.espirit.firstspirit.ui.operations.RequestOperation;
import de.espirit.firstspirit.webedit.WebeditUiAgent;

import java.io.PrintWriter;
import java.io.Writer;
import java.util.Map;
import java.util.ResourceBundle;


public class TextBlocksDropHandlerExecutable implements Executable {

	static final String MESSAGE_BUNDLE = "de.espirit.firstspirit.opt.example.universal.report.ReportMessages";


	@SuppressWarnings("UseOfSystemOutOrSystemErr")
	@Override
	public Object execute(final Map<String, Object> context) {
		return execute(context, new PrintWriter(System.out, true), new PrintWriter(System.err, true));
	}


	/**
	 * Determine which action (click or drop) was performed on the calling FS_BUTTON instance and display a message box
	 * with information about the action.
	 *
	 * @param context root context
	 * @param out     A writer object for logging INFO-level messages.
	 * @param err     A writer object for logging ERROR-level messages.
	 * @return A status value.
	 */
	@Override
	public Object execute(final Map<String, Object> context, final Writer out, final Writer err) {
		// Acquire a BaseContext object from the key-value pair context object passed as a parameter.
		final BaseContext scriptContext = (BaseContext) context.get("context");

		// Initialize the resource bundle for localized message texts.
		final ResourceBundle resourceBundle = ResourceBundle.getBundle(MESSAGE_BUNDLE, scriptContext.requireSpecialist(WebeditUiAgent.TYPE).getDisplayLanguage().getLocale());

		// Acquire general FS_BUTTON action parameters.
		final Boolean drop = (Boolean) context.get("drop");
		final CommodityContainer dropData = (CommodityContainer) context.get("dropdata");

		// Initialize an OperationAgent and a RequestOperation to display a message box in the client user interface.
		final OperationAgent operationAgent = scriptContext.requireSpecialist(OperationAgent.TYPE);
		final RequestOperation requestOperation = operationAgent.getOperation(RequestOperation.TYPE);
		if (requestOperation == null) {
			return 1;
		}
		final String messageBoxTitle = resourceBundle.getString("TextBlocksDropHandlerExecutable.title");
		requestOperation.setTitle(messageBoxTitle);

		if (drop && dropData != null) {
			// A drop has been performed; drop data is present.
			final TransferAgent transferAgent = scriptContext.requireSpecialist(TransferAgent.TYPE);
			if (!dropData.get(transferAgent.getStringType()).isEmpty()) {
				// The user dropped a text segment onto the button.
				final String dropMessage = resourceBundle.getString("TextBlocksDropHandlerExecutable.drop.string.intro") + " - " + resourceBundle.getString("TextBlocksDropHandlerExecutable.drop.string.flavor") + ": " + transferAgent.getStringType().getDataFlavor().getMimeType() + " - " + resourceBundle.getString("TextBlocksDropHandlerExecutable.drop.string.text") + ": " + dropData.get(transferAgent.getStringType());
				requestOperation.perform(dropMessage);
			} else if (!dropData.get(transferAgent.getExternalType()).isEmpty()) {
				// The user dropped a file from an external source onto the button.
				final String dropMessage = resourceBundle.getString("TextBlocksDropHandlerExecutable.drop.external.intro");
				requestOperation.perform(dropMessage);
			} else {
				// The user dropped another data type onto the button.
				final String dropMessage = resourceBundle.getString("TextBlocksDropHandlerExecutable.drop.other.intro");
				requestOperation.perform(dropMessage);
			}
		} else if (drop) {
			// It seems a drop has been performed, but no usable data has been provided.
			final String dropMessage = resourceBundle.getString("TextBlocksDropHandlerExecutable.drop.nodata");
			requestOperation.perform(dropMessage);
		} else {
			// A click action has been performed ((Boolean) drop == false).
			final String clickMessage = resourceBundle.getString("TextBlocksDropHandlerExecutable.click");
			requestOperation.perform(clickMessage);
		}
		return 0;
	}
}
