package de.espirit.firstspirit.opt.example.universal.report;

import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;


/**
 * Defines an object for use in reports based on {@link TextBlocksReportPlugin}.
 */
public class TextBlocksObject {

	private final String _title;
	private final String _text;
	private final String _imageFileName;


	/**
	 * Constructor. Stores {@link String} objects for title, text and a thumbnail image in fields.
	 *
	 * @param title	A short title used to enable users to quickly identify this object as it is displayed in a report.
	 * @param text	 The text of this object. This should be the most significant content and will be used by {@link
	 *                 TextBlocksDataRenderer} to specify transfer data for drag-and-drop operations.
	 * @param imageFileName The file name of a thumbnail image. These image files MUST be located in the same Java
	 *                         package for the JavaClient and rolled out into the file system of the project-specific
	 *                      web application for WebEdit!
	 */
	TextBlocksObject(@Nullable final String title, @NotNull final String text, @Nullable final String imageFileName) {
		_title = title;
		_text = text;
		_imageFileName = imageFileName;
	}


	/**
	 * Provides the "title" of this object.
	 *
	 * @return The title part of this object. If the {@link TextBlocksObject} does not contain a title, "No Title" is
	 *         returned.
	 */
	public String getTitle() {
		return _title != null ? _title : "No Title";
	}


	/**
	 * Provides the text stored in this object.
	 *
	 * @return The text part of this object.
	 */
	@Nullable
	public String getText() {
		return _text;
	}


	/**
	 * Provides the path to a thumbnail image file.
	 *
	 * @return The absolute or relative URL to the thumbnail image file.
	 */
	@Nullable
	public String getImageFileName() {
		return _imageFileName;
	}

}
