package de.espirit.firstspirit.opt.example.universal.report;

import de.espirit.firstspirit.client.plugin.report.Parameter;
import de.espirit.firstspirit.client.plugin.report.ParameterBoolean;
import de.espirit.firstspirit.client.plugin.report.ParameterSelect;
import de.espirit.firstspirit.client.plugin.report.ParameterText;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.ResourceBundle;


/**
 * Container type providing pre-defined parameter definitions for text block data filtering.
 */
public class TextBlocksParameters {

	public final ParameterText text;
	public final ParameterBoolean bool;
	public final ParameterSelect select;


	TextBlocksParameters(final ResourceBundle resourceBundle) {
		// Configure the constant text parameter that will be used to provide a search term text field in the report's filter area.
		text = Parameter.Factory.createText("pattern_text", resourceBundle.getString("TextBlocksReportPlugin.searchhint"), null);

		// Configure the constant boolean parameter that will be used to generate a "Search in titles only" checkbox in the report's filter area.
		bool = Parameter.Factory.createBoolean("pattern_boolean", resourceBundle.getString("TextBlocksReportPlugin.searchonlytitles"), false);

		// Create several selection options in order to configure a constant select parameter that will be used to generate a dropdown list in the report's filter area, allowing the user to influence sorting behavior.
		final ArrayList<ParameterSelect.SelectItem> selectPatternItems = new ArrayList<>();
		selectPatternItems.add(Parameter.Factory.createSelectItem(resourceBundle.getString("TextBlocksReportPlugin.sortorder.ascending"), "ascending"));
		selectPatternItems.add(Parameter.Factory.createSelectItem(resourceBundle.getString("TextBlocksReportPlugin.sortorder.descending"), "descending"));
		select = Parameter.Factory.createSelect("pattern_select", selectPatternItems, "ascending");
	}


	List<Parameter<?>> toList() {
		return Arrays.<Parameter<?>>asList(text, bool, select);
	}

}
