package de.espirit.firstspirit.opt.example.universal.report;

import de.espirit.firstspirit.access.BaseContext;
import de.espirit.firstspirit.agency.TransferAgent;
import de.espirit.firstspirit.client.plugin.report.TransferHandler;
import de.espirit.firstspirit.ui.gadgets.aspects.transfer.TransferType;

import org.jetbrains.annotations.NotNull;

import java.util.Collections;
import java.util.List;


public class TextBlocksTransferHandler implements TransferHandler<TextBlocksObject> {

	private final BaseContext _context;


	public TextBlocksTransferHandler(final BaseContext context) {
		_context = context;
	}


	@Override
	public void registerSuppliers(@NotNull final SupplierHost<TextBlocksObject> host) {
		final TransferAgent transferAgent = _context.requireSpecialist(TransferAgent.TYPE);

		// Register the Supplier implementation TextBlocksPlainTextSupplier with the plain-text TransferType.
		final TransferType<String> plainTextType = transferAgent.getPlainTextType();
		final SupplierHost.Supplier<TextBlocksObject, String> plainTextSupplier = new TextBlocksPlainTextSupplier();
		host.registerSupplier(plainTextType, plainTextSupplier);

		// Register the Supplier implementation TextBlocksHtmlTextSupplier with the HTML text TransferType.
		final TransferType<String> htmlTextType = transferAgent.getHtmlTextType();
		final SupplierHost.Supplier<TextBlocksObject, String> htmlTextSupplier = new TextBlocksHtmlTextSupplier();
		host.registerSupplier(htmlTextType, htmlTextSupplier);
	}


	/**
	 * Supplier implementation providing a {@link List} of {@link String} objects with plain-text data for a given {@link TextBlocksObject}.
	 */
	private static class TextBlocksPlainTextSupplier implements SupplierHost.Supplier<TextBlocksObject, String> {

		/**
		 * Supply a singleton {@link List} containing just the example text of a {@link TextBlocksObject}.
		 * @param object The example text blocks object to process.
		 * @return A {@link List} of {@link String} objects.
		 */
		@Override
		public List<String> supply(@NotNull final TextBlocksObject object) {
			return Collections.singletonList(object.getText());
		}
	}

	/**
	 * Supplier implementation providing a {@link List} of {@link String} objects with HTML data for a given {@link TextBlocksObject}.
	 */
	private static class TextBlocksHtmlTextSupplier implements SupplierHost.Supplier<TextBlocksObject, String> {

		/**
		 * Supply a singleton {@link List} containing the title of a {@link TextBlocksObject} formatted as an HTML link,
		 * including the text block's example text as the A tag's title attribute.
		 * @param object The example text blocks object to process.
		 * @return A {@link List} of {@link String} objects.
		 */
		@Override
		public List<String> supply(@NotNull final TextBlocksObject object) {
			return Collections.singletonList("<a title=\"" + object.getText() + "\"><b>" + object.getTitle() + "</b></a>");
		}
	}
}
