package de.espirit.firstspirit.opt.example.webedit.status;

import de.espirit.firstspirit.access.BaseContext;
import de.espirit.firstspirit.access.Task;
import de.espirit.firstspirit.access.User;
import de.espirit.firstspirit.access.store.IDProvider;
import de.espirit.firstspirit.webedit.WebeditColor;
import de.espirit.firstspirit.webedit.plugin.status.WebeditStatusNote;
import de.espirit.firstspirit.webedit.plugin.status.WebeditStatusNoteContext;
import de.espirit.firstspirit.webedit.plugin.status.WebeditStatusNotePlugin;

import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.Collections;
import java.util.List;


/**
 * Simple status plugin that informs the user about personal workflow tasks.
 */
public class WorkflowStatusNotePlugin implements WebeditStatusNotePlugin {

	@NotNull
	@Override
	public List<WebeditStatusNote> getStatusNotes(@NotNull final WebeditStatusNoteContext context) {
		final WebeditStatusNote note = createNote(context);
		return note != null ? Collections.singletonList(note) : Collections.<WebeditStatusNote>emptyList();
	}


	@Override
	public void setUp(@NotNull final BaseContext context) {
	}


	@Override
	public void tearDown() {
	}


	@Nullable
	private WebeditStatusNote createNote(final WebeditStatusNoteContext context) {
		final IDProvider element = context.getElement();
		final Task task = element.getTask();
		if (task != null) {
			// element has workflow running
			final User currentUser = element.getProject().getUserService().getUser();
			final boolean personalTask = task.getEditors().contains(currentUser);
			return context.createNote()
					.color(personalTask ? WebeditColor.PEPPERMINT : WebeditColor.SHARK)
					.title(personalTask ? "Your Task" : "Workflow in progress")
					.text(personalTask ? "This element waits for you!" : "This element waits for somebody.")
					.visibleOnLoad(personalTask)
					.create();
		}
		return null;
	}


}
